Module channel

Module channel 

Structs

MpscFdReceiver
Receiver half of an MpscFd pair
MpscFdSender
Sender half of an MpscFd pair

Enums

RecvError
RecvTimeoutError
SendError
TryRecvError
TrySendError

Functions

mpsc_fd_pair
Create a new MpscFd pair (sender and receiver). This acts like a std::sync::mpsc channel, but with a file descriptor associated with each end. The file descriptor may be polled with libc::poll or libc::select to wait for data to be available alongside other file descriptors.