MpscFdReceiver

Struct MpscFdReceiver 

pub struct MpscFdReceiver<T> { /* private fields */ }
Receiver half of an MpscFd pair

Implementations

Source

impl<T> MpscFdReceiver<T>

pub fn recv(&mut self) -> Result<T, RecvError>

Receive a message from the mpsc channel and read a byte from the pipe.

pub fn try_recv(&mut self) -> Result<T, TryRecvError>

Try to receive a message without blocking.

Readability of the fd is a hint that this will likely return a value, however this may return Empty and leave the fd readable in certain cases.

pub fn recv_timeout(&mut self, timeout: Duration) -> Result<T, RecvTimeoutError>

Receive with timeout. Note that this may block slightly more than timeout if the pipe was written but the channel was not.

Readability of the fd is a hint that this will likely return a value, however this may return Empty and leave the fd readable in certain cases.