pub struct MpscFdSender<T> { /* private fields */ }Expand description
Sender half of an MpscFd pair
Implementations
Sourceimpl<T> MpscFdSender<T>
impl<T> MpscFdSender<T>
Sourcepub fn try_send(&mut self, msg: T) -> Result<(), TrySendError<T>>
pub fn try_send(&mut self, msg: T) -> Result<(), TrySendError<T>>
Send a message through the mpsc channel and write a byte to the pipe. Fails immediately if the pipe is full.
Sourcepub fn blocking_send(&mut self, msg: T) -> Result<(), SendError<T>>
pub fn blocking_send(&mut self, msg: T) -> Result<(), SendError<T>>
Send a message through the mpsc channel and block until the message is sent.
This may not be fair in the case of multiple senders.
pub fn try_clone(&self) -> Result<Self>