Structs
- Mpsc
FdReceiver - Receiver half of an MpscFd pair
- Mpsc
FdSender - Sender half of an MpscFd pair
Enums
Functions
- mpsc_
fd_ pair - Create a new MpscFd pair (sender and receiver). This acts like a
std::sync::mpscchannel, but with a file descriptor associated with each end. The file descriptor may be polled withlibc::pollorlibc::selectto wait for data to be available alongside other file descriptors.